@@ -19,15 +19,17 @@ import sys
 from halo import Halo
 from pathlib import Path
 from sqlalchemy.exc import IntegrityError
+from sqlalchemy import inspect
 from time import sleep
 from tabulate import tabulate
+from shutil import get_terminal_size
 
 from wilfred.docker_conn import docker_client
 from wilfred.version import version, commit_hash, commit_date
 from wilfred.api.config_parser import Config, NoConfiguration
 from wilfred.database import session, database_path, Server, EnvironmentVariable
 from wilfred.api.servers import Servers
-from wilfred.api.images import Images, ImageAPIMismatch
+from wilfred.api.images import Images, ImageAPIMismatch, ImagesOutdated
 from wilfred.message_handler import warning, error, ui_exception
 from wilfred.core import is_integer, random_string, check_for_new_releases
 from wilfred.migrate import Migrate
@@ -46,7 +48,12 @@ except Exception as e:
 
 
 images = Images()
-servers = Servers(docker_client(), config.configuration, images)
+
+if not os.environ.get("WILFRED_SKIP_DOCKER", False):
+    try:
+        servers = Servers(docker_client(), config.configuration, images)
+    except Exception as e:
+        ui_exception(e)
 
 if not images.check_if_present():
     with Halo(
@@ -67,6 +74,18 @@ except ImageAPIMismatch:
         images.read_images()
     except Exception as e:
         ui_exception(e)
+except ImagesOutdated:
+    with Halo(
+        text="Images outdated, refreshing default images",
+        color="yellow",
+        spinner="dots",
+    ) as spinner:
+        images.download()
+        spinner.succeed("Images refreshed")
+    try:
+        images.read_images()
+    except Exception as e:
+        ui_exception(e)
 except Exception as e:
     ui_exception(e)
 
@@ -91,6 +110,7 @@ def print_version(ctx, param, value):
         else ""
     )
 
+    check_for_new_releases(enable_emojis=ENABLE_EMOJIS)
     if str(version) == "0.0.0.dev0":
         click.echo(
             "".join(
@@ -101,7 +121,6 @@ def print_version(ctx, param, value):
             )
         )
     else:
-        check_for_new_releases(enable_emojis=ENABLE_EMOJIS)
         click.echo(
             "".join(
                 (
@@ -137,6 +156,36 @@ def print_path(ctx, param, value):
     ctx.exit()
 
 
+def pretty_list(data, tablefmt):
+    for server in data:
+        server.update(
+            (
+                k,
+                str(v)
+                .replace("running", click.style("running", fg="green"))
+                .replace("stopped", click.style("stopped", fg="red"))
+                .replace("installing", click.style("installing", fg="yellow")),
+            )
+            for k, v in server.items()
+        )
+
+    headers = {
+        "id": click.style("ID", bold=True),
+        "name": click.style("Name", bold=True),
+        "image_uid": click.style("Image UID", bold=True),
+        "memory": click.style("RAM", bold=True),
+        "port": click.style("Port", bold=True),
+        "status": click.style("Status", bold=True),
+        "custom_startup": click.style("Custom startup", bold=True),
+    }
+
+    return tabulate(
+        data,
+        headers=headers,
+        tablefmt=tablefmt,
+    )
+
+
 def main():
     # snap packages raise some weird ASCII codec errors, so we just force C.UTF-8
     if (
@@ -151,10 +200,20 @@ def main():
 
 @click.group()
 @click.option(
-    "--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True
+    "--version",
+    is_flag=True,
+    callback=print_version,
+    expose_value=False,
+    is_eager=True,
+    help="Print version and exit",
 )
 @click.option(
-    "--path", is_flag=True, callback=print_path, expose_value=False, is_eager=True
+    "--path",
+    is_flag=True,
+    callback=print_path,
+    expose_value=False,
+    is_eager=True,
+    help="Print paths for configurations and server data",
 )
 def cli():
     """
@@ -192,24 +251,48 @@ def setup():
 def servers_list():
     """List all existing servers."""
 
-    click.echo(servers.pretty())
+    # run sync to refresh server state
+    servers.sync()
+
+    data = servers.all()
+
+    click.echo(
+        pretty_list(
+            data,
+            tablefmt="plain" if get_terminal_size((80, 20))[0] < 96 else "fancy_grid",
+        )
+    )
 
 
 @cli.command("images")
 @click.option("--refresh", help="Download the default images from GitHub", is_flag=True)
-def list_images(refresh):
+@click.option(
+    "--repo",
+    help="Specify repo to fetch images from during image refresh",
+    default="wilfred-dev/images",
+    show_default=True,
+)
+@click.option(
+    "--branch",
+    help="Specify branch to fetch images from during image refresh",
+    default="master",
+    show_default=True,
+)
+def list_images(refresh, repo, branch):
     """List images available on file."""
 
     if refresh:
-        with Halo(text="Refreshing images", color="yellow", spinner="dots") as spinner:
+        with Halo(
+            text=f"Refreshing images [{repo}/{branch}]", color="yellow", spinner="dots"
+        ) as spinner:
             try:
-                images.download()
+                images.download(repo=repo, branch=branch)
                 images.read_images()
             except Exception as e:
                 spinner.fail()
                 ui_exception(e)
 
-            spinner.succeed("Images refreshed")
+            spinner.succeed(f"Images refreshed [{repo}/{branch}]")
 
     click.echo(
         tabulate(
@@ -224,6 +307,17 @@ def list_images(refresh):
         )
     )
 
+    updated_at = click.style(
+        images.image_fetch_date.strftime("%Y-%m-%d %H:%M:%S"), bold=True
+    )
+    will_refresh_in = click.style(
+        str(images.image_time_to_refresh).split(".")[0], bold=True
+    )
+
+    click.echo(
+        f"Default images last updated at {updated_at}, will refresh in {will_refresh_in}"
+    )
+
 
 @cli.command()
 @click.option(
@@ -232,7 +326,9 @@ def list_images(refresh):
     is_flag=True,
 )
 @click.option(
-    "--detach", help="Immediately detach during install.", is_flag=True,
+    "--detach",
+    help="Immediately detach during install.",
+    is_flag=True,
 )
 @click.pass_context
 @configuration_present
@@ -360,7 +456,7 @@ def sync_cmd():
         spinner.succeed("Servers synced")
 
 
-@cli.command()
+@cli.command(short_help="Start server")
 @click.argument("name")
 @click.option(
     "--console", help="Attach to server console immediately after start.", is_flag=True
@@ -369,8 +465,9 @@ def sync_cmd():
 @configuration_present
 def start(ctx, name, console):
     """
-    Start server by specifiying the
-    name of the server as argument.
+    Start server
+
+    NAME is the name of the server
     """
 
     try:
@@ -414,13 +511,15 @@ def start(ctx, name, console):
             ctx.invoke(server_console, name=name)
 
 
-@cli.command()
+@cli.command(short_help="Forcefully kill running server")
 @click.argument("name")
-@click.option("-f", "--force", is_flag=True)
+@click.option("-f", "--force", is_flag=True, help="Force action without confirmation")
 @configuration_present
 def kill(name, force):
     """
-    Forcefully kill running server.
+    Forcefully kill running server
+
+    NAME is the name of the server
     """
 
     if force or click.confirm(
@@ -444,12 +543,14 @@ def kill(name, force):
             spinner.succeed("Server killed")
 
 
-@cli.command()
+@cli.command(short_help="Stop server gracefully")
 @click.argument("name")
 @configuration_present
 def stop(name):
     """
     Stop server gracefully.
+
+    NAME is the name of the server
     """
 
     try:
@@ -485,7 +586,7 @@ def stop(name):
         spinner.succeed("Server stopped")
 
 
-@cli.command()
+@cli.command(short_help="Restart server")
 @click.argument("name")
 @click.option(
     "--console", help="Attach to server console immediately after start.", is_flag=True
@@ -494,8 +595,9 @@ def stop(name):
 @configuration_present
 def restart(ctx, name, console):
     """
-    Restart server by specifiying the
-    name of the server as argument.
+    Restart server
+
+    NAME is the name of the server
     """
 
     ctx.invoke(stop, name=name)
@@ -507,11 +609,13 @@ def restart(ctx, name, console):
 
 @cli.command()
 @click.argument("name")
-@click.option("-f", "--force", is_flag=True)
+@click.option("-f", "--force", is_flag=True, help="Force action without confirmation")
 @configuration_present
 def delete(name, force):
     """
     Delete existing server.
+
+    NAME is the name of the server
     """
 
     if force or click.confirm(
@@ -532,13 +636,17 @@ def delete(name, force):
                 ui_exception(e)
 
 
-@cli.command("command")
+@cli.command("command", short_help="Send command to STDIN of server")
 @click.argument("name")
 @click.argument("command")
 @configuration_present
 def run_command(name, command):
     """
     Send command to STDIN of server
+
+    \b
+    NAME is the name of the server
+    COMMAND is the command to send, can be put in \" for commands with whitespaces
     """
 
     server = session.query(Server).filter_by(name=name.lower()).first()
@@ -570,7 +678,9 @@ def run_command(name, command):
 @configuration_present
 def server_console(name):
     """
-    Attach to server console, view log and run commands.
+    Attach to server console, view log and run commands
+
+    NAME is the name of the server
     """
 
     server = session.query(Server).filter_by(name=name.lower()).first()
@@ -609,6 +719,8 @@ def server_console(name):
 def edit(name):
     """
     Edit server (name, memory, port, environment variables)
+
+    NAME is the name of the server
     """
 
     server = session.query(Server).filter_by(name=name.lower()).first()
@@ -616,7 +728,17 @@ def edit(name):
     if not server:
         error("Server does not exist", exit_code=1)
 
-    click.echo(servers.pretty(server=server))
+    click.echo(
+        pretty_list(
+            [
+                {
+                    c.key: getattr(server, c.key)
+                    for c in inspect(server).mapper.column_attrs
+                }
+            ],
+            tablefmt="plain" if get_terminal_size((80, 20))[0] < 96 else "fancy_grid",
+        )
+    )
     click.echo("Leave values empty to use existing value")
 
     name = click.prompt("Name", default=server.name).lower()
@@ -710,7 +832,19 @@ def edit(name):
 def top():
     while True:
         # retrieve data (this can take a split moment)
-        data = servers.pretty_data(cpu_load=True, memory_usage=True)
+        data = servers.all(cpu_load=True, memory_usage=True)
+
+        for server in data:
+            server.update(
+                (
+                    k,
+                    str(v)
+                    .replace("running", click.style("running", fg="green"))
+                    .replace("stopped", click.style("stopped", fg="red"))
+                    .replace("installing", click.style("installing", fg="yellow")),
+                )
+                for k, v in server.items()
+            )
 
         # clear the screen
         click.clear()
@@ -728,7 +862,13 @@ def top():
         }
 
         # display table
-        click.echo(tabulate(data, headers=headers, tablefmt="plain",))
+        click.echo(
+            tabulate(
+                data,
+                headers=headers,
+                tablefmt="plain",
+            )
+        )
 
         # cooldown before repeating
         sleep(1)
@@ -746,6 +886,15 @@ def top():
 @click.argument("variable", required=False)
 @click.argument("value", required=False)
 def config_command(name, variable, value):
+    """
+    Manage server configuration (for supported filetypes)
+
+    \b
+    NAME is the name of the server
+    VARIABLE is the name of an available setting
+    VALUE is the new value for the variable setting
+    """
+
     def _get():
         return ServerConfig(config.configuration, servers, server, image)
 
